==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/help/ja-sjis/xtcntseqHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* R}hwv,man,musahi GUI ʃbZ[WǗ                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* R}h̃^Cg                                                         */
/* R}hwv̍ŏ̍sɕ\\                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "moTuXgǑ"

/*----------------------------------------------------------------------------*/
/* p[^                                                                 */
/* R}hwv USAGE:Ƃ"L[[h XXXT"\\ ex)-k L[ږXg*/
/* flag̃IvV̓R}hwvOPTIONS)Ƃĕ\\ ex)-z : Wo͂̈k*/
/*----------------------------------------------------------------------------*/
/*-k*/
#define KEYT "L[ږXg"
#define KEYC "V[PXJEgPʂƂȂ鍀ږXg"

/*-u*/
#define UNTT "V[PXPʍږXg"
#define UNTC "̃V[PX̒PʂƂȂ鍀ږXg"

/*-f*/
#define FLDT "V[PX\\ږ"
#define FLDC "Ŏw肵ڂV[PXƂ݂Ȃ"
#define FLDF NULL

/*-s*/
#define SRTT "׊鍀ږXg"
#define SRTC "L[ږŎw肵Pʍs̒ŁAV[PX̏Ԃ߂邽߂̍ږw肷"
#define SRTF "l,t"

/*-c*/
#define CNTT ""
#define CNTC "̃p[^ɂāAo͂錏𐧌łB"

/*-p*/
#define PCTT "p[Zg"
#define PCTC "̃p[^ɂāAo͂錏AŕmõV[PX̌ɑ΂銄ɂĐłBftHg 10 łB"

/*-l*/
#define LENT "V[PX͈̒"
#define LENC "̃p[^ɂāAo͂V[PX̒𐧌łBftHg 2_5 łBŏl:1,ől50B"

/*-Q*/
#define SSQT "subsequencěƂ߂"
#define SSQC "substringɑウsubsequencȅo߂"

/*-x*/
#define XMLT "XMLɂo"
#define XMLC "o͂XMLtablełȂXMĽ`łȂB"

/*-a*/
#define FNMT C_FNMT
#define FNMC C_FNMC

/*-q*/
#define SEQT C_SEQT
#define SEQC C_SEQC

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/* v                                                                       */
/* R}hwvSUMMARY:Ƃĕ\\                                     */
/* HTMLwvmanɂ́AHELPD̏Ɍ`ŕ\\                   */
/*----------------------------------------------------------------------------*/
#define HELPS "-kŎw肵ڂ̒lsɂāA-fŎw肵ڂ̒lV[PXƂĂƂ炦A̕V[PX̌JEgB"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtcntsubstr -k ڋq,t -s  -f X -idat.trn -Idat.tst\n\
xtcntsubstr -k ڋq,t -s  -f X -c 1000 -idat.trn -Idat.tst\n\
xtcntsubstr -k ڋq,t -s  -f X -l 10_30 -idat.trn -Idat.tst\n\
"

/*----------------------------------------------------------------------------*/
/* QƃR}h(KJ}ŋ؂A󔒂͗pȂ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR ""

/*----------------------------------------------------------------------------*/
/* ҂ɂ                                                               */
/* R}hwvɂ͕\\Ȃ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* oO|[g                                                               */
/* o^΃R}hwvBUG REPORT:ɕ\\B                  */
/* o^Ȃ(#define HELPB "")\\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* z[y[W                                                               */
/* o^΃R}hwvINFORMATION:ɕ\\B                 */
/* o^Ȃ(#define HELPH "")\\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-core-1.0.4-pre3.tar.gz: musashi-core-1.0.4-pre3/help/ja-sjis/xtcntseqHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* R}hwv,man,musahi GUI ʃbZ[WǗ                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* R}h̃^Cg                                                         */
/* R}hwv̍ŏ̍sɕ\                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "moTuXgǑ"

/*----------------------------------------------------------------------------*/
/* p[^                                                                 */
/* R}hwv USAGE:Ƃ"L[[h XXXT"\ ex)-k L[ږXg*/
/* flag̃IvV̓R}hwvOPTIONS)Ƃĕ\ ex)-z : Wo͂̈k*/
/*----------------------------------------------------------------------------*/
/*-k*/
#define KEYT "L[ږXg"
#define KEYC "V[PXJEgPʂƂȂ鍀ږXg"

/*-u*/
#define UNTT "V[PXPʍږXg"
#define UNTC "̃V[PX̒PʂƂȂ鍀ږXg"

/*-f*/
#define FLDT "V[PX\ږ"
#define FLDC "Ŏw肵ڂV[PXƂ݂Ȃ"
#define FLDF NULL

/*-s*/
#define SRTT "׊鍀ږXg"
#define SRTC "L[ږŎw肵Pʍs̒ŁAV[PX̏Ԃ߂邽߂̍ږw肷"
#define SRTF "l,t"

/*-c*/
#define CNTT ""
#define CNTC "̃p[^ɂāAo͂錏𐧌łB"

/*-p*/
#define PCTT "p[Zg"
#define PCTC "̃p[^ɂāAo͂錏AŕmõV[PX̌ɑ΂銄ɂĐłBftHg 10 łB"

/*-l*/
#define LENT "V[PX͈̒"
#define LENC "̃p[^ɂāAo͂V[PX̒𐧌łBftHg 2_5 łBŏl:1,ől50B"

/*-Q*/
#define SSQT "subsequencěƂ߂"
#define SSQC "substringɑウsubsequencȅo߂"

/*-x*/
#define XMLT "XMLɂo"
#define XMLC "o͂XMLtablełȂXMĽ`łȂB"

/*-a*/
#define FNMT C_FNMT
#define FNMC C_FNMC

/*-q*/
#define SEQT C_SEQT
#define SEQC C_SEQC

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/* v                                                                       */
/* R}hwvSUMMARY:Ƃĕ\                                     */
/* HTMLwvmanɂ́AHELPD̏Ɍ`ŕ\                   */
/*----------------------------------------------------------------------------*/
#define HELPS "-kŎw肵ڂ̒lsɂāA-fŎw肵ڂ̒lV[PXƂĂƂ炦A̕V[PX̌JEgB"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtcntsubstr -k ڋq,t -s  -f X -idat.trn -Idat.tst\n\
xtcntsubstr -k ڋq,t -s  -f X -c 1000 -idat.trn -Idat.tst\n\
xtcntsubstr -k ڋq,t -s  -f X -l 10_30 -idat.trn -Idat.tst\n\
"

/*----------------------------------------------------------------------------*/
/* QƃR}h(KJ}ŋ؂A󔒂͗pȂ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR ""

/*----------------------------------------------------------------------------*/
/* ҂ɂ                                                               */
/* R}hwvɂ͕\Ȃ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* oO|[g                                                               */
/* o^΃R}hwvBUG REPORT:ɕ\B                  */
/* o^Ȃ(#define HELPB "")\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* z[y[W                                                               */
/* o^΃R}hwvINFORMATION:ɕ\B                 */
/* o^Ȃ(#define HELPH "")\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
